/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas;


/**
 * DefaultConstraintManager provides the basic behavior and structure for
 * ConstraintManagers.
 *
 * @version $Revision: 1.2 $
 * @author Christophe Laprun
 */
public class DefaultConstraintManager implements ConstraintManager {

  /** Default constructor. */
  public DefaultConstraintManager() {
    constraints = new ConstraintSet();
    enabledConstraints = new ConstraintSet();
  }

  public ConstraintSet getAllConstraints() {
    return constraints;
  }

  public ConstraintSet getEnabledConstraints() {
    return enabledConstraints;
  }

  public boolean enableConstraint(String name, boolean enabled) {
    Constraint c = enabledConstraints.getConstraintWithName(name);
    // c is enabled and we want to disable it
    if (!enabled && c != null) {
      enabledConstraints.removeConstraint(c);
      return true;
    }
    // c is disabled and we want to enable it
    if (enabled && c == null && constraints.containsConstraintWithName(name)) {
      enabledConstraints.addConstraint(constraints.getConstraintWithName(name));
      return true;
    }
    // other cases: do nothing so no changes
    return false;
  }

  private ConstraintSet constraints;
  private ConstraintSet enabledConstraints;
}

