/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas;

import gov.nist.atlas.util.ATLASElementSet;


/**
 * FeaturesHolder defines behavior expected from objects holding Features.
 *
 * @version $Revision: 1.2 $
 * @author Christophe Laprun
 *
 * @see Feature
 */
public interface FeaturesHolder {
  /**
   * Returns the Feature subordinate identified with the specified role.
   *
   * @param role the role identifying the Feature to retrieve
   *
   * @return the Feature subordinate identified with the specified role,
   * <code>null</code> if no such Feature is contained in this FeaturesHolder
   */
  Feature getFeatureWithRole(String role);

  /**
   * Returns all the Feature subordinates contained in this FeaturesHolder.
   *
   * @return a possibly empty ATLASElementSet containing this
   * FeaturesHolder's Feature subordinates
   */
  ATLASElementSet getAllFeatures();

  /**
   * Assigns the specified Feature to the subordinate identified with
   * the given role.
   *
   * @param feature the new value for the subordinate
   * @param role the role identifying the Feature subordinate to be set
   *
   * @return <code>true</code> if the assignement was correctly done,
   * <code>false</code> otherwise
   */
  boolean setFeatureWithRole(Feature feature, String role);
}

