/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.event;

/**
 * An Exception that is raised when a change on the value of a Parameter has
 * been denied by a ContentWillChangeListener. It is up to the developers to
 * provide relevant information as to why the change was vetoed in the context
 * of a ContentChangedVetoException.
 *
 * @version $Revision: 1.2 $
 * @author Nicolas Radde
 *
 * @see ContentWillChangeListener
 * @see gov.nist.atlas.Validatable
 */
public class ContentChangedVetoException extends Exception {

  /**
   * Creates a new ContentChangedVetoException with a default message.
   */
  public ContentChangedVetoException() {
    super("veto on the change !!!");
  }

  /**
   * Creates a new ContentChangedVetoException with a specified message.
   *
   * @param why a description of the reason why this Content
   * ChangedVetoException
   *            is thrown.
   */
  public ContentChangedVetoException(String why) {
    super(why);
  }

}