/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */
package gov.nist.atlas.io;

import gov.nist.atlas.util.ATLASImplementation;

/**
 * DefaultImportedElementBuilderFactory is the default implementation of the
 * ImportedElementBuilderFactory class. It provides access to the default
 * ImportedElementBuilder.
 *
 * @see ImportedElementBuilder
 */
public class DefaultImportedElementBuilderFactory extends ImportedElementBuilderFactory {

  /**
   * Creates a DefaultImportedElementBuilderFactory, whose ImportedElementBuilders
   * will use the ATLASElementFactory associted to the given ATLASImplementation to
   * build the ATLASElements.
   * @param implementation the ATLASImplementation associated to the
   *        ATLASElementFactory to use for ATLASElement creation.
   */
  public DefaultImportedElementBuilderFactory(ATLASImplementation implementation) {
    importedParameterBuilder = new ImportedParameterBuilder(implementation, this);
    importedAnchorBuilder = new ImportedAnchorBuilder(implementation, this);
    importedSignalBuilder = new ImportedSignalBuilder(implementation, this);
    importedRegionBuilder = new ImportedRegionBuilder(implementation, this);
    importedAnnotationBuilder = new ImportedAnnotationBuilder(implementation, this);
    importedFeatureBuilder = new ImportedFeatureBuilder(implementation, this);
    importedMetadataBuilder = new ImportedMetadataBuilder(implementation, this);
    importedAnalysisBuilder = new ImportedAnalysisBuilder(implementation, this);
    importedCorpusBuilder = new ImportedCorpusBuilder(implementation, this);
  }

  public ImportedParameterBuilder getImportedParameterBuilder() {
    return importedParameterBuilder;
  }

  public ImportedAnchorBuilder getImportedAnchorBuilder() {
    return importedAnchorBuilder;
  }

  public ImportedSignalBuilder getImportedSignalBuilder() {
    return importedSignalBuilder;
  }

  public ImportedRegionBuilder getImportedRegionBuilder() {
    return importedRegionBuilder;
  }

  public ImportedAnnotationBuilder getImportedAnnotationBuilder() {
    return importedAnnotationBuilder;
  }

  public ImportedFeatureBuilder getImportedFeatureBuilder() {
    return importedFeatureBuilder;
  }

  public ImportedMetadataBuilder getImportedMetadataBuilder() {
    return importedMetadataBuilder;
  }

  public ImportedAnalysisBuilder getImportedAnalysisBuilder() {
    return importedAnalysisBuilder;
  }

  public ImportedCorpusBuilder getImportedCorpusBuilder() {
    return importedCorpusBuilder;
  }


  private final ImportedParameterBuilder importedParameterBuilder;
  private final ImportedAnchorBuilder importedAnchorBuilder;
  private final ImportedSignalBuilder importedSignalBuilder;
  private final ImportedRegionBuilder importedRegionBuilder;
  private final ImportedAnnotationBuilder importedAnnotationBuilder;
  private final ImportedFeatureBuilder importedFeatureBuilder;
  private final ImportedMetadataBuilder importedMetadataBuilder;
  private final ImportedAnalysisBuilder importedAnalysisBuilder;
  private final ImportedCorpusBuilder importedCorpusBuilder;

}
