/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.util;


/**
 * @version $Revision: 1.2 $
 * @author Christophe Laprun
 */
public class DefaultATLASElementSetFactory extends ATLASElementSetFactory {
  public MutableATLASElementSet createMutableATLASElementSet(Object guard, int size, ATLASElementSetProperties properties) {
    boolean byId = properties.isBooleanPropertySet(ATLASElementSetProperties.ACCESS_BY_ID);
    ATLASElementSet set = null;

    if (byId) {
      boolean sortable = properties.isBooleanPropertySet(ATLASElementSetProperties.HEAVY_REORDERINGS);
      if (sortable)
        set = new SortableMapATLASElementSet(guard, size, properties);
      set = new MapATLASElementSet(guard, size, properties);
    }
    boolean fastGrowing = properties.isBooleanPropertySet(ATLASElementSetProperties.HEAVY_COUNT_CHANGES);
    if (fastGrowing)
      set = new LinkedListATLASElementSet(guard, size, properties);
    set = new ArrayListATLASElementSet(guard, size, properties);

    return MutableWrapper.createMutableWrapper(set);
  }

  public DefaultATLASElementSetFactory() {
  }

  public DefaultATLASElementSetFactory(ATLASImplementation implementation) {
    super(implementation);
  }

}


