/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.util;

import gov.nist.atlas.ATLASElement;

/**
 * <p>RoleAdressable is basically a role holder for any ATLASElement.</p>
 *
 * <p>It aims to enhance an ATLASElement with a role attribute. Such a refinement
 * only makes sense in the context of a parent Element  (for example, knowing
 * that an anchor has a role "start" is only relevant within a given region).
 * Subsequently, making an ATLASElement implement the RoleAdressable interface
 * is mostly intended for the creation of ATLASElements containing role
 * addressable sub-ATLASElements.</p>
 *
 * <p>ATLAS specifies the following ATLASElements as RoleAdressable :
 * <CODE>Analysis</CODE>, <CODE>Feature</CODE> and <CODE>Parameter</CODE>.</p>
 *
 * <P>A RoleAdressable must be created by calling the appropriate
 * RoleWrapper's method.</p>
 *
 * @version $Revision: 1.2 $
 * @author Christophe Laprun, Sylvain Pajot
 *
 * @see RoleWrapper
 */
public interface RoleAddressable {

  /**
   * Returns this RoleAddressable's role as defined in the context
   * of its parent.
   *
   * @return this RoleAddressable's role
   */
  String getRole();

  /**
   * Returns this RoleAddressable's ATLASElement.
   *
   * @return the ATLASElement
   */
  ATLASElement getElement();
}



